@@ -7,6 +7,7 @@
 # Edited on 06/10/2018
 # Edited on 09/12/2018
 # Edited on 01/05/2019
+# Edited on 01/13/2019 -- added CHMORTp
 
 ### Child mortality rates
 CHMORT5 <- function(Data.Name, PeriodEnd = NULL) {
@@ -75,6 +76,67 @@ CHMORT5 <- function(Data.Name, PeriodEnd = NULL) {
       list(mort_res)
     }
 
+### Child mortality probabilities
+CHMORTp <- function(Data.Name, PeriodEnd = NULL) {
+  ageseg <- list(c(0, 1), c(1, 3), c(3, 6), c(6, 12), c(12, 24), c(24, 36), c(36, 48), c(48, 60))
+  names(ageseg) <- c("0", "1-2", "3-5", "6-11", "12-23", "24-35", "36-47", "48-59")
+
+  deathprobn <- numeric(length = 8)
+  names(deathprobn) <- names(ageseg)
+  deathprobd <- numeric(length = 8)
+  names(deathprobd) <- names(ageseg)
+  wdeathprob <- numeric(length = 8)
+  names(wdeathprob) <- names(ageseg)
+  wdeathprobn <- numeric(length = 8)
+  names(wdeathprobn) <- names(ageseg)
+  wdeathprobd <- numeric(length = 8)
+  names(wdeathprobd) <- names(ageseg)
+
+  for (i in seq_along(ageseg)) {
+    segdata <- Data.Name[which((Data.Name$b7 >= ageseg[[i]][1]) | is.na(Data.Name$b7)), ]
+
+    segdata$exposure <- NA
+
+    segdata$exposure[segdata$b3 >= (segdata$tl - ageseg[[i]][2]) &
+                       segdata$b3 < (segdata$tl - ageseg[[i]][1]) ] <- 0.5
+
+    segdata$exposure[segdata$b3 >= (segdata$tl - ageseg[[i]][1]) &
+                       segdata$b3 < (segdata$tu - ageseg[[i]][2]) ] <- 1
+
+    segdata$exposure[segdata$b3 >= (segdata$tu - ageseg[[i]][2]) &
+                       segdata$b3 < (segdata$tu - ageseg[[i]][1]) ] <- 0.5
+
+    segdata$death <- NA
+
+    segdata$death[segdata$b3 >= (segdata$tl - ageseg[[i]][2]) &
+                    segdata$b3 < (segdata$tl - ageseg[[i]][1]) &
+                    (segdata$b7 >= ageseg[[i]][1] & segdata$b7 < ageseg[[i]][2])] <- 0.5
+
+    segdata$death[segdata$b3 >= (segdata$tl - ageseg[[i]][1]) &
+                    segdata$b3 < (segdata$tu - ageseg[[i]][2]) &
+                    (segdata$b7 >= ageseg[[i]][1] & segdata$b7 < ageseg[[i]][2])] <- 1
+
+    segdata$death[segdata$b3 >= (segdata$tu - ageseg[[i]][2]) &
+                    segdata$b3 < (segdata$tu - ageseg[[i]][1]) &
+                    (segdata$b7 >= ageseg[[i]][1] & segdata$b7 < ageseg[[i]][2])] <- ifelse(is.null(PeriodEnd) , 1, 0.5)
+
+    segdata$death[is.na(segdata$b7)] <- 0
+
+    wdeathprob[names(ageseg)[i]] <- sum(segdata$death * segdata$rweight, na.rm = TRUE) /
+      (sum(segdata$exposure * segdata$rweight, na.rm = TRUE))
+    wdeathprobn[names(ageseg)[i]] <- sum(segdata$death * segdata$rweight, na.rm = TRUE)
+    wdeathprobd[names(ageseg)[i]] <- sum(segdata$exposure * segdata$rweight, na.rm = TRUE)
+    deathprobn[names(ageseg)[i]] <- sum(segdata$death, na.rm = TRUE)
+    deathprobd[names(ageseg)[i]] <- sum(segdata$exposure, na.rm = TRUE)
+  }
+
+  CHMORT8 <- cbind.data.frame(round(wdeathprob, 4), round(wdeathprobn,2), round(wdeathprobd,2),
+                              round(deathprobn,2), round(deathprobd,2))
+
+  names(CHMORT8) <- c("PROBABILITY", "W.DEATHS", "W.EXPOSURE", "DEATHS", "EXPOSURE")
+
+  list(CHMORT8)[[1]]
+}
 
 ### N: Total births contributed to the calculations
 NBIRTHS <- function(Data.Name) {
@@ -105,7 +167,6 @@ NBIRTHS <- function(Data.Name) {
       list(BirthN)
     }
 
-
 ### WN: Total births contributed to the calculations _ weighted
 NBIRTHSW <- function(Data.Name) {
       BirthNg <- list(c(0, 1), c(1, 12), c(0, 12), c(12, 60), c(0, 60))
@@ -134,7 +195,6 @@ NBIRTHSW <- function(Data.Name) {
       list(BirthNW)
     }
 
-
 ### DEFT: design effect
 DEFT <- function(Data.Name) {
       BirthNg <- list(c(0, 1), c(1, 12), c(0, 12), c(12, 60), c(0, 60))
